@@ -33,8 +33,15 @@
 #define SEC	 1000000
 #define T_REPLY	    (1*SEC)	/* 1 sec */
 #define R_REPLY	    5		/* 5 retries */
-#define T_REVAL	    (30*SEC)	/* 30 sec - make much larger (if srv ...) @@@ */
-#define R_REVAL	    0		/* no retries */
+#ifdef FREQUENT_REVAL
+#define T_CREVAL    (30*SEC)	/* 30 sec, client */
+#define T_SREVAL    (35*SEC)	/* 35 sec, server */
+#else
+#define T_CREVAL   (600*SEC)	/* 10 min, client (RFC1577: <= 15 min) */
+#define T_SREVAL  (1500*SEC)	/* 25 min, server (RFC1577: >= 20 min) */
+#endif
+#define R_CREVAL    0		/* no retries */
+#define R_SREVAL    0		/* no retries */
 #define T_RETRY	    (1*SEC)	/* 1 sec */
 #define R_RETRY	    25000	/* enough try keep trying during a long
 				   weekend */
@@ -470,7 +477,8 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
     if (entry->state != as_valid && !entry->vccs && itf->arp_srv)
 	connect_me(entry);
     if ((entry->flags & ATF_ARPSRV) || !(entry->flags & ATF_PERM))
-	START_TIMER(entry,REVAL);
+	if (entry->itf->arp_srv) START_TIMER(entry,CREVAL);
+	else START_TIMER(entry,SREVAL);
     entry->state = as_valid;
 }
 
@@ -691,7 +699,7 @@ static int ioctl_set_pvc(ITF *itf,unsigned long ip,
     vcc->connecting = 0;
     vcc->fd = fd;
     vcc->entry = entry;
-    if (!(flags & ATF_PERM)) START_TIMER(entry,REVAL);
+    if (!(flags & ATF_PERM)) START_TIMER(entry,CREVAL);
     Q_INSERT_HEAD(entry->vccs,vcc);
     Q_INSERT_HEAD(itf->table,entry);
     return 0;
@@ -712,7 +720,9 @@ static int ioctl_set_svc(ITF *itf,unsigned long ip,
     *entry->addr = *addr;
     entry->qos = *qos;
     entry->flags = flags;
-    if (!(flags & ATF_PERM) || (flags & ATF_ARPSRV)) START_TIMER(entry,REVAL);
+    if (!(flags & ATF_PERM) || (flags & ATF_ARPSRV))
+	if (itf->arp_srv) START_TIMER(entry,CREVAL);
+	else START_TIMER(entry,SREVAL);
     entry->itf = itf;
     Q_INSERT_HEAD(itf->table,entry);
     if (flags & ATF_ARPSRV) {
