@@ -42,6 +42,7 @@ static int kernel,incoming,inet;
 void open_all(void)
 {
     struct sockaddr_atmsvc addr;
+    struct atm_qos qos;
     struct atm_blli blli;
 
     if ((kernel = socket(PF_ATMSVC,SOCK_DGRAM,0)) < 0)
@@ -50,9 +51,12 @@ void open_all(void)
 	diag(COMPONENT,DIAG_FATAL,"ioctl ATMARPD_CTRL: %s",strerror(errno));
     if ((incoming = socket(PF_ATMSVC,SOCK_DGRAM,ATM_AAL5)) < 0)
 	diag(COMPONENT,DIAG_FATAL,"socket: %s",strerror(errno));
+    memset(&qos,0,sizeof(qos));
+    qos.rxtp.class = qos.txtp.class = ATM_ANYCLASS;
+    if (setsockopt(incoming,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0)
+	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
     memset(&addr,0,sizeof(addr));
     addr.sas_family = AF_ATMSVC;
-    addr.sas_rxtp.class = ATM_UBR; /* compatible with everything else */
     addr.sas_addr.bhli.hl_type = ATM_HL_NONE;
     addr.sas_addr.blli = &blli;
     blli.l2_proto = ATM_L2_ISO8802;
@@ -221,15 +225,10 @@ static void accept_new(void)
 	}
     }
 #endif
-    entry = alloc_t(ENTRY);
+    entry = alloc_entry(1);
     entry->state = as_invalid;
-    entry->svc = 1;
-    entry->ip = 0;
     entry->addr = alloc_t(struct sockaddr_atmsvc);
     *entry->addr = addr;
-    entry->flags = 0;
-    entry->vccs = NULL;
-    entry->itf = NULL;
     Q_INSERT_HEAD(unknown_incoming,entry);
     vcc->entry = entry;
     Q_INSERT_HEAD(entry->vccs,vcc);
@@ -240,7 +239,7 @@ static void accept_new(void)
 }
 
 
-int connect_vcc(struct sockaddr *remote,int timeout)
+int connect_vcc(struct sockaddr *remote,const struct atm_qos *qos,int timeout)
 {
     int fd,flags;
 
@@ -259,12 +258,16 @@ int connect_vcc(struct sockaddr *remote,int timeout)
 	printf("\n");
     }
    ((struct sockaddr_atmsvc *) local)->sas_addr.bhli.hl_type = 1; /* uuuh @@@ */
-	if (bind(fd,local,sizeof(struct sockaddr_atmsvc)) < 0) {
-	    diag(COMPONENT,DIAG_ERROR,"bind: %s",strerror(errno));
-	    return -errno;
-	}
+    if (bind(fd,local,sizeof(struct sockaddr_atmsvc)) < 0) {
+	diag(COMPONENT,DIAG_ERROR,"bind: %s",strerror(errno));
+	return -errno;
+    }
 }
 #endif
+    if (setsockopt(fd,SOL_ATM,SO_ATMQOS,qos,sizeof(*qos)) < 0) {
+	diag(COMPONENT,DIAG_ERROR,"setsockopt SO_ATMQOS: %s",strerror(errno));
+	return -errno;
+    }
     if ((flags = fcntl(fd,F_GETFL)) < 0) {
 	diag(COMPONENT,DIAG_ERROR,"fcntl F_GETFL: %s",strerror(errno));
 	return -errno;
@@ -421,12 +424,12 @@ int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask)
 
     sprintf(req.ifr_ifrn.ifrn_name,"atm%d",number);
     if (ioctl(inet,SIOCGIFADDR,&req) < 0) {
-	diag(COMPONENT,DIAG_FATAL,"ioctl SIOCGIFADDR: %s",strerror(errno));
+	diag(COMPONENT,DIAG_ERROR,"ioctl SIOCGIFADDR: %s",strerror(errno));
 	return -1;
     }
     *ip = ((struct sockaddr_in *) &req.ifr_ifru.ifru_addr)->sin_addr.s_addr;
     if (ioctl(inet,SIOCGIFNETMASK,&req) < 0) {
-	diag(COMPONENT,DIAG_FATAL,"ioctl SIOCGIFNETMASK: %s",strerror(errno));
+	diag(COMPONENT,DIAG_ERROR,"ioctl SIOCGIFNETMASK: %s",strerror(errno));
 	return -1;
     }
     *netmask = ((struct sockaddr_in *) &req.ifr_ifru.ifru_netmask)->
