@@ -1,6 +1,6 @@
 /* itf.c - IP interface registry */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -11,6 +11,7 @@
 #include "table.h"
 #include "io.h"
 #include "itf.h"
+#include "arp.h"
 
 
 #define COMPONENT "ITF"
@@ -48,6 +49,11 @@ void itf_up(int number)
     ITF *itf;
 
     diag(COMPONENT,DIAG_DEBUG,"ITF UP %d",number);
+    for (itf = itfs; itf; itf = itf->next)
+	if (itf->number == number) {
+	    diag(COMPONENT,DIAG_ERROR,"interface is already active");
+	    return;
+	}
     itf = alloc_t(ITF);
     if (ip_itf_info(number,&itf->local_ip,&itf->netmask) < 0) {
 	free(itf);
@@ -61,6 +67,20 @@ void itf_up(int number)
 
 void itf_down(int number)
 {
+    ITF *itf;
+    ENTRY *entry,*next;
+
     diag(COMPONENT,DIAG_DEBUG,"ITF DOWN %d",number);
-    /* should remove interface */
+    for (itf = itfs; itf; itf = itf->next)
+	if (itf->number == number) break;
+    if (!itf) {
+	diag(COMPONENT,DIAG_ERROR,"no such interface");
+	return;
+    }
+    for (entry = itf->table; entry; entry = next) {
+	next = entry->next;
+	discard_entry(entry);
+    }
+    Q_REMOVE(itfs,itf);
+    free(itf);
 }
