@@ -496,43 +496,6 @@ void la_config (HANDLE     la_elan_handle,
 --*/
 void la_elan_reset (HANDLE   la_elan_handle);
 
-/*++
-* ==================
-* = la_arp_resolve =
-* ==================
-*
-* Overview:
-*   Attempt to resolve a MAC address to a data-direct VCC for transmission.
-*   This call returns a transmit action value that indicates what should be
-*   done with the transmit packet.
-*
-* Arguments:
-*   la_elan_handle  - (IN)  Handle returned by la_register.
-*   addr            - (IN)  Destination MAC Address being resolved.
-*   p_action        - (OUT) Action indication:
-*                             - XMT_DISCARD - The packet must be discarded.
-*                             - XMT_FLOOD   - The packet may be transmitted on
-*                                             the broadcast channel.
-*                             - XMT_FORWARD - The packet may be transmitted on
-*                                             the indicated data-direct VCC.
-*   p_conn_handle   - (OUT) Handle of data-direct VCC to be used if p_action is
-*                           XMT_FORWARD.
-*
-* Returns:
-*   None
-*
-* Preconditions:
-*   None
-*
-* Postconditions:
-*   The LE-ARP cache has knowledge of the MAC address and is attempting to
-*   establish or maintain the mapping from that address to a data-direct VCC.
---*/
-void la_arp_resolve (HANDLE        la_elan_handle,
-                     ESI           esi,
-                     XMT_ACTION   *p_action,
-                     HANDLE       *p_conn_handle);
-
 /*++
 * ===============
 * = la_perm_add =
@@ -603,7 +566,7 @@ STATUS la_perm_add (HANDLE    la_elan_handle,
 *   LE-ARP cache with a matching ESI.
 --*/
 STATUS la_addr_delete (HANDLE    la_elan_handle,
-                       ESI       esi,
+                       unsigned char *atm_addr,
                        BOOLEAN   permanent);
 
 /*++
@@ -695,106 +658,3 @@ void la_flush_complete (HANDLE   la_elan_handle,
 void la_topology_change_set (HANDLE  la_elan_handle,
                              BOOLEAN topology_change_flag);
 
-/*++
-* ===============
-* = la_vc_added =
-* ===============
-*
-* Overview:
-*   Called by the LEC_CTRL module after an SVC is opened.
-*   The LEC_ARP module may then allow the use of this SVC as a data direct
-*   connection.
-*
-* Arguments:
-*   la_elan_handle  - (IN) Handle returned by la_register.
-*   conn_handle     - (IN) Connection handle of the new VCC.
-*
-* Returns:
-*   None.
-*
-* Preconditions:
-*   The connection handle is valid.
-*
-* Postconditions:
-*   None
---*/
-void la_vc_added (HANDLE la_elan_handle,
-                  HANDLE conn_handle);
-
-/*++
-* ===============
-* = la_attr_get =
-* ===============
-*
-* Overview:
-*   Get a management attribute for an ELAN instance.  Refer to lec_mgt.h for
-*   a list of attribute IDs.
-*
-* Arguments:
-*   la_elan_handle    - (IN)  Handle returned by la_register.
-*   attr_id           - (IN)  ID of attribute to be accessed.
-*   p_out_buffer      - (IN)  Pointer to the output buffer to be filled with
-*                             data.
-*   out_buffer_length - (IN)  Number of bytes writable in the output buffer.
-*   p_bytes_written   - (OUT) Number of bytes written.
-*
-* Returns:
-*   STATUS_K_SUCCESS       - Successful Completion.
-*   STATUS_K_ARG_2_BAD     - Invalid Attribute ID.
-*   STATUS_K_ARG_4_BAD     - Not enough space in output buffer.
-*   STATUS_K_NOT_FOUND     - Instance not found.
-*
-* Preconditions:
-*   None
-*
-* Postconditions:
-*   None
---*/
-STATUS la_attr_get (HANDLE     la_elan_handle,
-                    UINT16     attr_id,
-                    void      *p_out_buffer,
-                    UINT16     out_buffer_length,
-                    UINT16    *p_bytes_written);
-
-STATUS la_attr_get_next (HANDLE     elan_handle,
-                         UINT16     attr_id,
-                         void      *p_in_buffer,
-                         UINT16     in_buffer_length,
-                         void      *p_out_buffer,
-                         UINT16     out_buffer_length,
-                         UINT16    *p_bytes_written);
-
-/*++
-* ===============
-* = la_attr_set =
-* ===============
-*
-* Overview:
-*   Set a management attribute for an ELAN instance.  Refer to lec_mgt.h for
-*   a list of attribute IDs.
-*
-* Arguments:
-*   la_elan_handle    - (IN)  Handle returned by la_register.
-*   attr_id           - (IN)  ID of attribute to be accessed.
-*   p_in_buffer       - (IN)  Pointer to the input buffer that contains data
-*                             to be written.
-*   in_buffer_length  - (IN)  Number of bytes to be written.
-*
-* Returns:
-*   STATUS_K_SUCCESS       - Successful Completion.
-*   STATUS_K_ARG_2_BAD     - Invalid Attribute ID.
-*   STATUS_K_ARG_5_BAD     - Not enough space in output buffer.
-*   STATUS_K_NOT_FOUND     - Instance not found.
-*   STATUS_K_NO_PRIVELEGE  - Attempted to write a Read-Only attribute.
-*
-* Preconditions:
-*   None
-*
-* Postconditions:
-*   None
---*/
-STATUS la_attr_set (HANDLE     la_elan_handle,
-                    UINT16     attr_id,
-                    void      *p_in_buffer,
-                    UINT16     in_buffer_length);
-
