@@ -164,7 +164,7 @@ static int try_e164(const char *text,struct sockaddr_atmsvc *addr,int flags)
 {
     int i,dot,result;
 
-    if (*text == ':') text++;
+    if (*text == ':' || *text == '+') text++;
     for (i = dot = 0; *text; text++)
 	if (isdigit(*text)) {
 	    if (i == ATM_E164_LEN) return TRY_OTHER; /* too long */
