@@ -230,8 +230,10 @@ int main(int argc,char **argv)
 		break;
 	    case 'd':
 		set_verbosity(NULL,DIAG_DEBUG);
+		set_verbosity("QMSG",DIAG_INFO);
+		set_verbosity("SSCOP",DIAG_INFO);
 		debug = 1;
-		q_dump = 1;
+		/*q_dump = 1;*/
 		break;
 	    case 'l':
 		set_logfile(optarg);
@@ -246,8 +248,17 @@ int main(int argc,char **argv)
 		usage(argv[0]);
 	}
     if (optind != argc) usage(argv[0]);
-    diag(COMPONENT,DIAG_INFO,"Linux ATM signaling UNI 3.x(red)/AAL5, version "
-      VERSION);
+    diag(COMPONENT,DIAG_INFO,"Linux ATM signaling "
+#ifdef UNI30
+      "UNI 3.0"
+#endif
+#ifdef UNI31
+      "UNI 3.1"
+#ifdef ALLOW_UNI30
+      "+3.0compat"
+#endif
+#endif
+      "/AAL5, version " VERSION);
     if (!(yyin = fopen(config_file,"r")))
 	diag(COMPONENT,DIAG_WARN,"%s not found. - Using defaults.",config_file);
     else if (yyparse()) {
