@@ -51,14 +51,13 @@ static int send_setup(SOCKET *sock)
 				     this */
 #endif
     q_assign(&dsc,QF_sscs_type,0); /* unspecified - LANE wants this */
-    error = sap_encode(&dsc,sock->remote);
+    error = sap_encode(&dsc,sock->remote,&sock->qos);
     q_assign(&dsc,QF_bearer_class,16); /* BCOB-X */
     q_assign(&dsc,QF_traf_type,0); /* force presence - UNI 3.0 wants this */
     q_assign(&dsc,QF_upcc,0); /* p2p */
 #ifndef UNI30
     q_assign(&dsc,QF_qos_cs,Q2931_CS_ITU);
 #endif
-    q_assign(&dsc,QF_qos_cs,Q2931_CS_NET);
     q_assign(&dsc,QF_qos_fw,0); /* QOS 0 */
     q_assign(&dsc,QF_qos_bw,0);
     local = NULL;
@@ -96,7 +95,14 @@ static int send_connect(SOCKET *sock)
     q_assign(&dsc,QF_msg_type,QMSG_CONNECT);
     q_assign(&dsc,QF_call_ref,sock->call_ref);
     if (sock->ep_ref >= 0) q_assign(&dsc,QF_ep_ref,sock->ep_ref);
-    /* @@@ lots of data */
+    q_assign(&dsc,QF_aal_type,5);
+#ifdef UNI30
+    q_assign(&dsc,QF_aal_mode,1); /* Message mode - LANE seems to really want
+				     this */
+#endif
+    q_assign(&dsc,QF_sscs_type,0); /* unspecified - LANE wants this */
+    q_assign(&dsc,QF_fw_max_sdu,sock->qos.rxtp.max_sdu);
+    q_assign(&dsc,QF_bw_max_sdu,sock->qos.txtp.max_sdu);
     if ((size = q_close(&dsc)) >= 0) to_signaling(q_buffer,size);
     return 0;
 }
@@ -131,6 +137,10 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
     switch (msg->type) {
 	case as_bind: /* only in NULL state */
 	    if (sock) break;
+	    if (msg->aal != ATM_AAL5) {
+		SEND_ERROR(msg->vcc,-EINVAL);
+		return;
+	    }
 	    if (!*msg->svc.sas_addr.pub && !*msg->svc.sas_addr.prv)
 #ifdef BE_PICKY_ABOUT_BINDING_LOCAL_WILDCARD_ADDRESSES
 		if (local_addr[0].state != ls_same)
@@ -138,7 +148,7 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		else
 #endif
 		send_kernel(msg->vcc,0,as_okay,0,NULL,NULL,
-		      &local_addr[0].addr);
+		      &local_addr[0].addr,NULL);
 	    else {
 		LOCAL_ADDR *walk;
 
@@ -147,36 +157,35 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 		      &msg->svc,0,0)) break;
 		if (walk->state == ls_unused)
 		    SEND_ERROR(msg->vcc,-EADDRNOTAVAIL);
-		else send_kernel(msg->vcc,0,as_okay,0,NULL,NULL,NULL);
+		else send_kernel(msg->vcc,0,as_okay,0,NULL,NULL,NULL,NULL);
 	    }
 	    return;
-	case as_establish: /* NULL or LISTENING */
-	    if (sock && sock->state != ss_listening) break;
-	    if (!sock) {
-		sock = new_sock(msg->vcc);
-		error = bind_check(sock,&msg->local);
-		if (!error) {
-		    sock->remote = sap_copy(&msg->svc);
-		    if (!sock->remote) error = -EINVAL;
-		}
-		if (error) {
-		    free_sock(sock);
-		    SEND_ERROR(msg->vcc,error);
-		    return;
-		}
-		sock->pvc.sap_txtp = sock->remote->sas_txtp;
-		sock->pvc.sap_rxtp = sock->remote->sas_rxtp;
-		sock->state = ss_connecting;
-		error = send_setup(sock);
-		if (error) {
-		    SEND_ERROR(msg->vcc,error);
-		    free_sock(sock);
-		    return;
-		}
-		START_TIMER(sock,T303);
-		new_state(sock,ss_connecting);
+	case as_connect: /* NULL state only */
+	    if (sock) break;
+	    sock = new_sock(msg->vcc);
+	    error = bind_check(sock,&msg->local);
+	    if (!error) {
+		sock->remote = sap_copy(&msg->svc);
+		if (!sock->remote) error = -EINVAL;
+	    }
+	    if (error) {
+		free_sock(sock);
+		SEND_ERROR(msg->vcc,error);
 		return;
 	    }
+	    sock->qos = msg->qos;
+	    sock->state = ss_connecting;
+	    error = send_setup(sock);
+	    if (error) {
+		SEND_ERROR(msg->vcc,error);
+		free_sock(sock);
+		return;
+	    }
+	    START_TIMER(sock,T303);
+	    new_state(sock,ss_connecting);
+	    return;
+	case as_accept: /* LISTENING only */
+	    if (sock->state != ss_listening) break;
 	    /* becomes INDICATED or ZOMBIE */
 	    if (!sock->listen) {
 		diag(COMPONENT,DIAG_WARN,
@@ -213,14 +222,15 @@ static void dispatch(SOCKET *sock,struct atmsvc_msg *msg)
 
 		if (sock) break;
 		sap = sap_copy(&msg->svc);
-		if (lookup_sap(sap,NULL)) {
+		if (lookup_sap(sap,&msg->qos,NULL,NULL)) {
 		    free(sap);
 		    SEND_ERROR(msg->vcc,-EADDRINUSE);
 		    return;
 		}
 		sock = new_sock(msg->vcc);
 		sock->local = sap_copy(&msg->svc);
-		send_kernel(sock->id,0,as_okay,0,NULL,NULL,NULL);
+		sock->qos = msg->qos;
+		send_kernel(sock->id,0,as_okay,0,NULL,NULL,NULL,NULL);
 		sock->state = ss_listening;
 		return;
 	    }
