@@ -32,6 +32,7 @@ typedef struct _socket {
     unsigned long id;
     struct sockaddr_atmsvc *local; /* local SAP */
     struct sockaddr_atmsvc *remote; /* remote SAP */
+    struct atm_qos qos; /* QOS parameters */
     int error; /* error code for close */
     /* --- Q.93B/Q.2931 information ---------------------------------------- */
     Q2931_STATE q2931_state;
@@ -66,7 +67,8 @@ extern int pretty;
   (int) sizeof(struct atm_blli)+1)
 #define bllis2msg(n) (sizeof(struct atmsvc_msg)+sizeof(struct atm_blli)*((n)-1))
 
-#define SEND_ERROR(vcc,code) send_kernel(vcc,0L,as_close,code,NULL,NULL,NULL)
+#define SEND_ERROR(vcc,code) \
+  send_kernel(vcc,0L,as_error,code,NULL,NULL,NULL,NULL)
 
 
 void from_kernel(struct atmsvc_msg *msg,int size);
@@ -74,8 +76,9 @@ void itf_load(int itf);
 
 void to_q2931(void *msg,int size);
 void send_kernel(unsigned long vcc,unsigned long listen_vcc,
-  enum atmsvc_msg_type type,int reply,struct sockaddr_atmpvc *pvc,
-  struct sockaddr_atmsvc *svc,struct sockaddr_atmsvc *local);
+  enum atmsvc_msg_type type,int reply,const struct sockaddr_atmpvc *pvc,
+  const struct sockaddr_atmsvc *svc,const struct sockaddr_atmsvc *local,
+  const struct atm_qos *qos);
 void from_net(void *msg,int size);
 void to_signaling(void *msg,int size);
 void saal_failure(void);
@@ -85,7 +88,8 @@ void clear_all_calls_on_T309(void);
 SOCKET *new_sock(unsigned long id);
 void free_sock(SOCKET *sock);
 void new_state(SOCKET *sock,STATE state);
-SOCKET *lookup_sap(struct sockaddr_atmsvc *sap,struct sockaddr_atmsvc **res);
+SOCKET *lookup_sap(const struct sockaddr_atmsvc *sap,const struct atm_qos *qos,
+  struct sockaddr_atmsvc **res_sap,struct atm_qos *res_qos);
 void send_release(SOCKET *sock,unsigned char reason,...);
 void send_release_complete(unsigned long call_ref,unsigned char cause);
 
