@@ -59,12 +59,13 @@ static void setup_call(unsigned long call_ref)
 {
     SOCKET *sock,*this,**walk;
     struct sockaddr_atmsvc *sap,*new_sap;
+    struct atm_qos qos,new_qos;
     unsigned char buf[ATM_ESA_LEN];
     int len,i;
 
-    sap = sap_decode(&in_dsc);
+    sap = sap_decode(&in_dsc,&qos);
     new_sap = NULL;
-    sock = lookup_sap(sap,&new_sap);
+    sock = lookup_sap(sap,&qos,&new_sap,&new_qos);
     if (!sock || new_sap) free(sap);
     else new_sap = sap; /* @@@ should strip extra BLLIs */
     if (!sock) {
@@ -79,6 +80,7 @@ static void setup_call(unsigned long call_ref)
 	this->ep_ref = q_fetch(&in_dsc,QF_ep_ref);
     send_call_proceeding(this);
     this->local = new_sap;
+    this->qos = new_qos;
     /* if (sock->local) *this->local->sas_addr = sock->local->sas_addr; ??? */
     diag(COMPONENT,DIAG_DEBUG,"AAL type %ld",q_fetch(&in_dsc,QF_aal_type));
     len = q_read(&in_dsc,QF_cdpn_esa,(void *) &buf,sizeof(buf));
@@ -99,8 +101,6 @@ static void setup_call(unsigned long call_ref)
       this->pvc.sap_addr.vpi,this->pvc.sap_addr.vci);
     this->remote = alloc_t(struct sockaddr_atmsvc);
     memset(this->remote,0,sizeof(struct sockaddr_atmsvc));
-    this->pvc.sap_txtp = this->remote->sas_txtp = new_sap->sas_txtp;
-    this->pvc.sap_rxtp = this->remote->sas_rxtp = new_sap->sas_rxtp;
     if (q_present(&in_dsc,QF_cgpn)) { /* should handle E.164 too */
 	char buffer[MAX_ATM_ADDR_LEN+1];
 
@@ -112,7 +112,7 @@ static void setup_call(unsigned long call_ref)
 	  pretty) < 0) strcpy(buffer,"<invalid address>");
 	diag(COMPONENT,DIAG_DEBUG,"Incoming call from %s",buffer);
     }
-    send_kernel(0,sock->id,as_indicate,0,&this->pvc,this->remote,NULL);
+    send_kernel(0,sock->id,as_indicate,0,&this->pvc,this->remote,NULL,&new_qos);
     for (walk = &sock->listen; *walk; walk = &(*walk)->listen);
     *walk = this;
     diag(COMPONENT,DIAG_DEBUG,"SE vpi.vci=%d.%d",this->pvc.sap_addr.vpi,
@@ -306,7 +306,8 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 	    send_connect_ack(sock);
 	    /* @@@ fill in sock->remote */
 	    /* @@@ fill in traffic parameters */
-	    send_kernel(sock->id,0,as_okay,0,&sock->pvc,NULL,sock->local);
+	    send_kernel(sock->id,0,as_okay,0,&sock->pvc,NULL,sock->local,
+	      &sock->qos);
 	    new_state(sock,ss_connected);
 	    diag(COMPONENT,DIAG_INFO,"Active open succeeded (CR 0x%06X)",
 	      sock->call_ref);
@@ -320,7 +321,7 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 	    }
 	    if (sock->state != ss_accepting) break;
 	    STOP_TIMER(sock);
-	    send_kernel(sock->id,0,as_okay,0,NULL,NULL,sock->local);
+	    send_kernel(sock->id,0,as_okay,0,NULL,NULL,sock->local,NULL);
 	    new_state(sock,ss_connected);
 	    diag(COMPONENT,DIAG_INFO,"Passive open succeeded (CR 0x%06X)",
 	      sock->call_ref);
@@ -408,8 +409,6 @@ static void q2931_call(SOCKET *sock,unsigned char mid)
 		    case ss_connected:
 			diag(COMPONENT,DIAG_INFO,"Passive close (CR 0x%06X)",
 			  sock->call_ref);
-			sock->error = -sock->error;
-			    /* context is still around */
 			send_close(sock);
 			/* fall through */
 		    case ss_hold:
