@@ -178,6 +178,7 @@ char **argv;
 {
     struct timeval td;
     unsigned long addr_tmp;
+    const char *port_name;
     int c;
     double mbps;
 int no_check = 0;
@@ -227,7 +228,7 @@ int no_check = 0;
 	    sinkmode = !sinkmode;
 	    break;
 	  case 'p':
-	    port = atoi(optarg);
+	    port_name = optarg;
 	    break;
 	  case 'P':
 	    pcr = atoi(optarg);
@@ -263,7 +264,22 @@ int no_check = 0;
 	    goto usage;
 	}
     }
-    
+
+    if (port_name)
+	if (atm) goto usage;
+	else {
+	    struct servent *se;
+
+	    se = getservbyname(port_name,udp ? "udp" : "tcp");
+	    if (se) port = ntohs(se->s_port);
+	    else {
+		const char *end;
+
+		port = strtoul(port_name,&end,0);
+		if (*end) goto usage;
+	    }
+	}     
+
     host = argv[optind];
     if (atm && arequipa) {
 	fprintf(stderr,"-Q must not be used with -a\n");
@@ -369,19 +385,27 @@ int no_check = 0;
     /* set socket buffer size */
 #if defined(SO_SNDBUF) || defined(SO_RCVBUF)
     if (sockbufsize) {
+int l;
 	if (trans) {
 	    /* set send socket buffer if we are transmitting */    
 	    if (setsockopt(fd, SOL_SOCKET, SO_SNDBUF, &sockbufsize,
 			   sizeof sockbufsize) < 0)
 		err("setsockopt: sndbuf");
+l = sizeof sockbufsize;
+if (getsockopt(fd, SOL_SOCKET, SO_SNDBUF, &sockbufsize, &l) < 0)
+perror("grr");
 	    mes("sndbuf");
 	} else {
 	    /* set receive socket buffer if we are receiving */    
 	    if (setsockopt(fd, SOL_SOCKET, SO_RCVBUF, &sockbufsize,
 			   sizeof sockbufsize) < 0)
 		err("setsockopt: rcvbuf");
+l = sizeof sockbufsize;
+if (getsockopt(fd, SOL_SOCKET, SO_RCVBUF, &sockbufsize, &l) < 0)
+perror("grr");
 	    mes("rcvbuf");
 	}
+printf("sbs=%d\n",sockbufsize);
     }
 #endif
 
@@ -421,6 +445,7 @@ int no_check = 0;
 		    err("setsockopt: nodelay");
 		mes("nodelay");
 	    }
+	    if (atm) sleep(1); /* grr ... */
 #endif
 	} else if (!arequipa || !udp) {
 	    /* otherwise, we are the server and 
